@@ -196,7 +196,12 @@ class L1CFile:
             header = data.attrs["FileHeader"].decode().split()[6:8]
             satellite = header[0].split("=")[1][:-1]
             sensor = header[1].split("=")[1][:-1]
-            self.sensor = sensors.get_sensor(sensor, platform=satellite)
+            date = self.start_time
+            self.sensor = sensors.get_sensor(
+                sensor,
+                platform=satellite,
+                date=self.start_time
+            )
 
 
     @property
@@ -259,6 +264,10 @@ class L1CFile:
                     axis=-1,
                 )
             )[0]
+            d_inds = np.diff(indices)
+            if any(d_inds > 1):
+                ind = np.where(d_inds > 1)[0]
+                indices = indices[:ind]
 
             with h5py.File(output_filename, "w") as output:
 
@@ -323,9 +332,40 @@ class L1CFile:
                                 name, shape=(n_scans,) + shape[1:], data=item[indices]
                             )
 
+                if "S3" in input.keys():
+                    g = output.create_group("S3")
+                    for name, item in input["S3"].items():
+                        if isinstance(item, h5py.Dataset):
+                            shape = item.shape
+                            g.create_dataset(
+                                name, shape=(n_scans,) + shape[1:], data=item[indices]
+                            )
+                    for a in input["S3"].attrs:
+                        s = input["S3"].attrs[a].decode()
+                        s = _RE_META_INFO.sub(f"NumberScansGranule={n_scans};", s)
+                        s = np.bytes_(s)
+                        g.attrs[a] = s
+
+                    g_st = g.create_group("ScanTime")
+                    for name, item in input["S3/ScanTime"].items():
+                        if isinstance(item, h5py.Dataset):
+                            shape = item.shape
+                            g_st.create_dataset(
+                                name, shape=(n_scans,) + shape[1:], data=item[indices]
+                            )
+
+                    g_sc = g.create_group("SCstatus")
+                    for name, item in input["S3/SCstatus"].items():
+                        if isinstance(item, h5py.Dataset):
+                            shape = item.shape
+                            g_sc.create_dataset(
+                                name, shape=(n_scans,) + shape[1:], data=item[indices]
+                            )
                 for a in input.attrs:
                     output.attrs[a] = input.attrs[a]
 
+        return indices.min(), indices.max()
+
     def extract_scans_and_pixels(self, scans, output_filename, n_pixels=-1):
         """
         Extract first pixel from each scan in file.
@@ -502,7 +542,7 @@ class L1CFile:
 
             lats_sc = input[f"{swath}/SCstatus/SClatitude"][indices]
             lons_sc = input[f"{swath}/SCstatus/SClongitude"][indices]
-            alt_sc = input[f"{swath}/SCstatus/SClongitude"][indices]
+            alt_sc = input[f"{swath}/SCstatus/SCaltitude"][indices]
 
             # Handle case that observations are split up.
             tbs = []
