@@ -104,8 +104,8 @@ def calculate_smoothing_kernels(sensor):
         A list of 2D Gaussian convolution kernels.
     """
     geometry = sensor.viewing_geometry
-    res_x_source = 14.4e3
-    res_a_source = 8.6e3
+    res_x_source = 4.5e3
+    res_a_source = 13.5e3
     angles = sensor.angles
     res_x_target = geometry.get_resolution_x(angles)
     res_a_target = geometry.get_resolution_a()
@@ -833,7 +833,9 @@ class ConstellationScanner(ConicalScanner):
         sim_file_pattern,
         sim_file_path,
         gmi_channels,
-        correction=None
+        correction=None,
+        modeling_error=None,
+        latitude_ratios=None
     ):
         super().__init__(
             name, channels, angles, platform, viewing_geometry,
@@ -841,9 +843,32 @@ class ConstellationScanner(ConicalScanner):
         )
         self.nedt = nedt
         self.gmi_channels=gmi_channels
-        self.correction = correction
         self.apply_biases = True
 
+        if correction is None:
+            self._correction = None
+        else:
+            self._correction = correction
+
+        self.modeling_error = modeling_error
+
+        # Calculate scence resampling factors
+        self._latitude_ratios = latitude_ratios
+
+    @property
+    def correction(self):
+        if self._correction is not None:
+            if not isinstance(self._correction, CdfCorrection):
+                self._correction = CdfCorrection(self._correction)
+        return self._correction
+
+    @property
+    def latitude_ratios(self):
+        if self._latitude_ratios is not None:
+            if not isinstance(self._latitude_ratios, np.ndarray):
+                self._latitude_ratios = np.load(self._latitude_ratios)
+        return self._latitude_ratios
+
     def load_brightness_temperatures(self, data, mask=None):
         """
         Load and bias-correct simulated brightness temperatures.
@@ -864,7 +889,6 @@ class ConstellationScanner(ConicalScanner):
 
             if self.apply_biases:
                 bias = load_variable(data, "brightness_temperature_biases")
-                # Apply scaling of biases
 
             if mask is not None:
                 bias = bias[mask]
@@ -874,7 +898,7 @@ class ConstellationScanner(ConicalScanner):
             tbs = load_variable(data, "brightness_temperatures", mask=mask)
         return tbs
 
-    def load_training_data_1d(self, dataset, targets, augment, rng):
+    def load_training_data_1d(self, dataset, targets, augment, rng, indices=None):
         """
         Load training data for GPROF-NN 1D retrieval. This function will
         only load pixels that with a finite surface precip value in order
@@ -889,6 +913,8 @@ class ConstellationScanner(ConicalScanner):
             targets: List of the targets to load.
             augment: Whether or not to augment the training data.
             rng: Numpy random number generator to use for augmentation.
+            indices: List of scene indices from which to load the data. This
+                can be used to resample training scenes.
 
         Return:
             Tuple ``(x, y)`` containing the un-batched, un-shuffled training
@@ -910,15 +936,17 @@ class ConstellationScanner(ConicalScanner):
 
         vs = [
             "simulated_brightness_temperatures",
-            "brightness_temperature_biases",
-            "earth_incidence_angle",
+            "brightness_temperature_biases"
         ]
         if "surface_precip" not in targets:
             vs += ["surface_precip"]
 
-        for i in range(n_samples):
-            scene = decompress_scene(dataset[{"samples": i}], targets + vs)
-            source = dataset.source[i]
+        if indices is None:
+            indices = range(n_samples)
+
+        for sample_index in indices:
+            scene = decompress_scene(dataset[{"samples": sample_index}], targets + vs)
+            source = dataset.source[sample_index]
 
             sp = scene["surface_precip"].data
             mask = sp >= 0
@@ -1007,6 +1035,7 @@ class ConstellationScanner(ConicalScanner):
         if augment:
             p_x_i = rng.random()
             p_y = rng.random()
+            p_x_o = rng.random()
         else:
             p_x_i = 0.5
             p_y = 0.5
@@ -1035,7 +1064,7 @@ class ConstellationScanner(ConicalScanner):
         st = scene.surface_type.data
 
         if self.correction is not None:
-            tbs = self.correction(self, st, eia, tcwv, tbs, augment=augment)
+            tbs = self.correction(self, st, None, tcwv, tbs, augment=augment)
 
         if augment:
             if self.nedt is not None:
@@ -1199,7 +1228,7 @@ class ConstellationScanner(ConicalScanner):
         return x, y
 
     def load_training_data_3d(
-        self, dataset, targets, augment, rng, width=32, height=128
+        self, dataset, targets, augment, rng, width=32, height=128, indices=None
     ):
         if isinstance(dataset, (str, Path)):
             dataset = xr.open_dataset(dataset)
@@ -1213,7 +1242,6 @@ class ConstellationScanner(ConicalScanner):
         vs = [
             "simulated_brightness_temperatures",
             "brightness_temperature_biases",
-            "earth_incidence_angle",
             "source",
             "latitude",
             "longitude",
@@ -1221,8 +1249,10 @@ class ConstellationScanner(ConicalScanner):
         if "surface_precip" not in targets:
             vs += ["surface_precip"]
 
-        for i in range(n):
-            scene = decompress_scene(dataset[{"samples": i}], targets + vs)
+        if indices is None:
+            indinces = range(n)
+        for sample_index in indices:
+            scene = decompress_scene(dataset[{"samples": sample_index}], targets + vs)
             source = scene.source
             if source == 0:
                 x_i, y_i = self._load_training_data_3d_sim(
@@ -1942,16 +1972,23 @@ MHS_NOAA19_FULL = CrossTrackScanner(
 )
 
 
-def get_sensor(sensor, platform=None):
+def get_sensor(sensor, platform=None, date=None):
     if platform is not None:
         platform = platform.upper().replace("-", "")
         key = f"{sensor.upper()}_{platform.upper()}"
-        try:
-            return globals()[key]
-        except KeyError:
-            pass
-    key = sensor.upper()
-    return globals()[key]
+        if key not in globals():
+            key = sensor.upper()
+    else:
+        key = sensor.upper()
+    sensor = globals()[key]
+    if sensor == TMI:
+        if date is not None:
+            if date > np.datetime64("2001-08-22T00:00:00"):
+                sensor = TMIPO
+            else:
+                sensor = TMIPR
+
+    return sensor
 
 ###############################################################################
 # TMI
@@ -1995,7 +2032,6 @@ TMI_NEDT = np.array([
 
 TMI_GMI_CHANNELS = [0, 1, 2, 3, 4, 6, 7, 8, 9]
 
-
 TMIPR_VIEWING_GEOMETRY = Conical(
     altitude=350e3,
     earth_incidence_angle=53.0,
@@ -2012,9 +2048,20 @@ TMIPO_VIEWING_GEOMETRY = Conical(
     scan_offset=13.4e3,
 )
 
+TMIPR_MODELING_ERROR = np.sqrt(np.array([
+    1.1,
+    2.4,
+    1.0,
+    2.6,
+    0.9,
+    2.0,
+    7.1,
+    2.4,
+    6.1
+]))
 
-TMIPR = ConstellationScanner(
-    "TMI",
+TMIPR_NC = ConstellationScanner(
+    "TMIPR",
     TMI_CHANNELS,
     TMI_NEDT,
     TMI_ANGLES,
@@ -2026,9 +2073,25 @@ TMIPR = ConstellationScanner(
     TMI_GMI_CHANNELS
 )
 
+TMIPR = ConstellationScanner(
+    "TMIPR",
+    TMI_CHANNELS,
+    TMI_NEDT,
+    TMI_ANGLES,
+    TRMM,
+    TMIPR_VIEWING_GEOMETRY,
+    None,
+    "TMIPR.dbsatTb.??????{day}.??????.sim",
+    "/qdata1/pbrown/dbaseV7/simV7_tmi",
+    TMI_GMI_CHANNELS,
+    correction=DATA_FOLDER / "corrections_tmipr.nc",
+    modeling_error=TMIPR_MODELING_ERROR,
+    latitude_ratios= DATA_FOLDER / "latitude_ratios_tmipr.npy"
+)
+
 
 TMIPO = ConstellationScanner(
-    "TMI",
+    "TMIPO",
     TMI_CHANNELS,
     TMI_NEDT,
     TMI_ANGLES,
@@ -2037,7 +2100,67 @@ TMIPO = ConstellationScanner(
     None,
     "TMIPO.dbsatTb.??????{day}.??????.sim",
     "/qdata1/pbrown/dbaseV7/simV7_tmi",
-    TMI_GMI_CHANNELS
+    TMI_GMI_CHANNELS,
+    correction=DATA_FOLDER / "corrections_tmipo.nc",
+    latitude_ratios= DATA_FOLDER / "latitude_ratios_tmipo.npy"
 )
 
 TMI = TMIPR
+
+###############################################################################
+# SSMI
+###############################################################################
+
+SSMI_CHANNELS = [
+    (19.35, "V"),
+    (19.35, "H"),
+    (22.235, "V"),
+    (37.0, "H"),
+    (37.0, "V"),
+    (85.5, "H"),
+    (85.5, "V"),
+]
+
+SSMI_ANGLES = np.array([
+    53.1,
+    53.1,
+    53.1,
+    53.1,
+    53.1,
+    53.1,
+    53.1,
+])
+
+SSMI_NEDT = np.array([
+    0.63,
+ 	0.54,
+ 	0.50,
+ 	0.47,
+ 	0.71,
+ 	0.36,
+ 	0.31,
+])
+
+SSMI_GMI_CHANNELS = [2, 3, 4, 6, 7, 8, 9]
+
+SSMI_VIEWING_GEOMETRY = Conical(
+    altitude=350e3,
+    earth_incidence_angle=53.0,
+    scan_range=130.0,
+    pixels_per_scan=208,
+    scan_offset=13.4e3,
+)
+
+SSMI = ConstellationScanner(
+    "SSMI",
+    SSMI_CHANNELS,
+    SSMI_NEDT,
+    SSMI_ANGLES,
+    TRMM,
+    SSMI_VIEWING_GEOMETRY,
+    None,
+    "SSMI.dbsatTb.??????{day}.??????.sim",
+    "/qdata1/pbrown/dbaseV7/simV7_ssmi",
+    SSMI_GMI_CHANNELS
+)
+
