@@ -1040,8 +1040,10 @@ class TrainingDataStatistics(Statistic):
         self.t2m_bins = np.linspace(239.5, 339.5, 101)
         self.tcwv = np.zeros((18, 100), dtype=np.float32)
         self.tcwv_bins = np.linspace(-0.5, 99.5, 101)
+        self.lat_bins = np.linspace(-90, 90, 181)
         self.st = np.zeros(18, dtype=np.float32)
         self.at = np.zeros(4, dtype=np.float32)
+        self.lats = np.zeros(180, dtype=np.float32)
 
         self.sums_tcwv = {}
         self.counts_tcwv = {}
@@ -1109,7 +1111,7 @@ class TrainingDataStatistics(Statistic):
         if self.kind.upper() == "1D":
             dataset = GPROF_NN_1D_Dataset(
                 filename,
-                targets=ALL_TARGETS,
+                targets=ALL_TARGETS + ["latitude"],
                 normalize=False,
                 shuffle=False,
                 augment=False,
@@ -1119,7 +1121,7 @@ class TrainingDataStatistics(Statistic):
         elif self.kind.upper() == "3D":
             dataset = GPROF_NN_3D_Dataset(
                 filename,
-                targets=ALL_TARGETS,
+                targets=ALL_TARGETS + ["latitude"],
                 normalize=False,
                 shuffle=False,
                 augment=False,
@@ -1206,6 +1208,9 @@ class TrainingDataStatistics(Statistic):
         bins = np.arange(-1, 4) + 0.5
         counts, _ = np.histogram(at, bins=bins)
         self.at += counts
+        lats = dataset["latitude"]
+        counts, _ = np.histogram(lats, bins=self.lat_bins)
+        self.lats += counts
 
     def merge(self, other):
         """
@@ -1220,6 +1225,7 @@ class TrainingDataStatistics(Statistic):
             self.tcwv = other.tcwv
             self.st = other.st
             self.at = other.at
+            self.lats = other.lats
             self.sums_tcwv = other.sums_tcwv
             self.counts_tcwv = other.counts_tcwv
 
@@ -1234,6 +1240,7 @@ class TrainingDataStatistics(Statistic):
             self.tcwv += other.tcwv
             self.st += other.st
             self.at += other.at
+            self.lats += other.lats
 
     def save(self, destination):
         """
@@ -1309,6 +1316,7 @@ class TrainingDataStatistics(Statistic):
 
         data["surface_type"] = ("surface_type_bins",), self.st
         data["airmass_type"] = ("airmass_type_bins"), self.st
+        data["latitudes"] = ("latitude_bins"), self.lats
 
         data = xr.Dataset(data)
 
@@ -1589,6 +1597,7 @@ class ObservationStatistics(Statistic):
         self.has_angles = None
         self.tbs = None
         self.tb_bins = np.linspace(0, 400, 401)
+        self.lat_bins = np.linspace(-90, 90, 181)
 
         self.t2m = np.zeros((18, 200), dtype=np.float32)
         self.t2m_bins = np.linspace(240, 330, 201)
@@ -1596,6 +1605,7 @@ class ObservationStatistics(Statistic):
         self.tcwv_bins = np.linspace(-0.5, 99.5, 101)
         self.st = np.zeros(18, dtype=np.float32)
         self.at = np.zeros(4, dtype=np.float32)
+        self.lats = np.zeros(180, dtype=np.float32)
 
     def _initialize_data(self, sensor, data):
         n_chans = sensor.n_chans
@@ -1692,6 +1702,10 @@ class ObservationStatistics(Statistic):
         counts, _ = np.histogram(at, bins=bins)
         self.at += counts
 
+        lats = dataset["latitude"].data
+        counts, _ = np.histogram(lats, bins=self.lat_bins)
+        self.lats += counts
+
         dataset.close()
         del dataset
 
@@ -1707,6 +1721,7 @@ class ObservationStatistics(Statistic):
             self.tcwv = other.tcwv
             self.st = other.st
             self.at = other.at
+            self.lats = other.lats
         elif other.tbs is not None:
             self.tbs += other.tbs
             self.tbs_tcwv += other.tbs_tcwv
@@ -1714,6 +1729,7 @@ class ObservationStatistics(Statistic):
             self.tcwv += other.tcwv
             self.st += other.st
             self.at += other.at
+            self.lats += other.lats
 
     def save(self, destination):
         """
@@ -1773,6 +1789,7 @@ class ObservationStatistics(Statistic):
 
         data["surface_type"] = ("surface_type_bins",), self.st
         data["airmass_type"] = ("airmass_type_bins"), self.st
+        data["latitudes"] = ("latitude_bins"), self.lats
 
         data = xr.Dataset(data)
 
